two_select_revisited
open | /demo/two_select_revisited.html |
assertText | first-master | animals machines
assertText | first-slave |
select | first-master | label=animals
waitForText | first-slave | dog cat cow
assertText | first-slave | dog cat cow
select | first-master | label=machines
waitForText | first-slave | computer car airplane
assertText | first-slave | computer car airplane
assertText | second-master | animals machines
assertText | second-slave |
select | second-master | label=animals
waitForText | second-slave | dog cat cow
assertText | second-slave | dog cat cow
select | second-master | label=machines
waitForText | second-slave | computer car airplane
assertText | second-slave | computer car airplane
assertText | third-master | animals machines
assertText | third-slave |
select | third-master | label=animals
waitForText | third-slave | dog cat cow
assertText | third-slave | dog cat cow
select | third-master | label=machines
waitForText | third-slave | computer car airplane
assertText | third-slave | computer car airplane